@@ -63,14 +63,14 @@ static int      death,
 		se,
 		nvar,
 		n;
-static void    addup();
+static void addup(int itime, double haz, double var);
 
-void agsurv3(Sint   *sn,    Sint   *snvar,    Sint   *sncurve, 
-	     Sint   *snpt,  Sint   *sse,      double *score, 
-	     double *sy,    Sint   *grpx,     double *r,        double *coef, 
-	     double *var,   double *xmean,    Sint   *scn, 
+void agsurv3(int    *sn,    int    *snvar,    int    *sncurve, 
+	     int    *snpt,  int    *sse,      double *score, 
+	     double *sy,    int    *grpx,     double *r,        double *coef, 
+	     double *var,   double *xmean,    int    *scn, 
 	     double *cy,    double *cx,       double *ssurv,
-	     double *varh,  double *sused,    Sint   *smethod)
+	     double *varh,  double *sused,    int    *smethod)
 {
 
     int i,j,k,l;
@@ -257,9 +257,7 @@ void agsurv3(Sint   *sn,    Sint   *snvar,    Sint   *sncurve,
     }
 
 
-static void addup(itime, haz, var)
-int itime;
-double haz, var;
+static void addup(int itime, double haz, double var)
     {
     int i, j, k, l;
     int     pstart,
