@@ -73,7 +73,12 @@ SEXP survreg7(SEXP maxiter2,   SEXP nvarx,  SEXP y,
     int nvar, nvar2, nvar3, nstrat;
     int iter;
     double newlk =0;
-    double (*dolik)();   /* will point to (*dolik) or survregc2 */
+    double (*dolik)(int n, int nvar, int nstrat, int whichcase,
+		    double *beta, int dist, int *strat, double *offset,
+		    double *time1, double *time2, double *status, double *wt,
+		    double **covar, double **imat, double **JJ, double *u, 
+		    SEXP expr, SEXP rho,   double *dummy, int nf,
+		    int *frail, double *fdiag, double *jdiag );   /* will point to (*dolik) or survregc2 */
     double x1, x2, x3, x4;
     double y1, y2, y3;
     int golden, goright;
@@ -81,10 +86,10 @@ SEXP survreg7(SEXP maxiter2,   SEXP nvarx,  SEXP y,
 
     /* pointers for the data regions of the input arguments */
     double **covar;
-    Sint   *strat ;
+    int    *strat ;
     double *time2, *time1, *status;
     double *offset;
-    Sint *fgrp;
+    int  *fgrp;
     double *wt;
 
     /* copies of the scalar input arguments */
@@ -113,7 +118,7 @@ SEXP survreg7(SEXP maxiter2,   SEXP nvarx,  SEXP y,
     double **hmat, **hinv, *beta, *hdiag;
     double *penalty;
     SEXP  rlist, rlistnames;
-    Sint *iter2, *flag;
+    int  *iter2, *flag;
     int nprotect;   /* number of PROTECT calls that I have issued */
 
     /*
